| Title: | Use Docker Images to Process Rmarkdown Blocks |
|---|---|
| Description: | Gives you the ability to use arbitrary Docker images (including custom ones) to process Rmarkdown code chunks. |
| Authors: | Ben Artin |
| Maintainer: | Ben Artin <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-06-07 07:26:17 UTC |
| Source: | https://github.com/cran/docknitr |
Create an alias for a Docker R markdown engine
docker_alias(name, ...)docker_alias(name, ...)
name |
The name of a new Docker R markdown engine |
... |
Options for the new Docker R markdown engine |
For example, after writing
docker_alias("ubuntu", image="ubuntu:latest", command="bash")
you can use ‘```{ubuntu}’ instead of ‘```{r engine="docker", image="ubuntu:latest", command="bash"}’ to process R markdown chunks through Ubuntu bash using Docker
The alias name must consist entirely of letters, digits, and underscores, or else 'knitr' will not recognize it as a valid code chunk in R markdown.
docker_alias("ubuntu", image="ubuntu:latest", command="bash")docker_alias("ubuntu", image="ubuntu:latest", command="bash")